// BaseView.cpp : implementation of the CBaseView class
//

#include "stdafx.h"
#include "Base.h"

#include "SectionSet.h"
#include "BaseDoc.h"
#include "BaseView.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CBaseView

IMPLEMENT_DYNCREATE(CBaseView, CRecordView)

BEGIN_MESSAGE_MAP(CBaseView, CRecordView)
	//{{AFX_MSG_MAP(CBaseView)
	ON_CBN_SELENDOK(IDC_COURSE, OnSelendokCourse)
	ON_COMMAND(ID_RECORD_ADD, OnRecordAdd)
	ON_COMMAND(ID_RECORD_DELETE, OnRecordDelete)
	ON_COMMAND(ID_RECORD_REFRESH, OnRecordRefresh)
	//}}AFX_MSG_MAP
	// Standard printing commands
	ON_COMMAND(ID_FILE_PRINT, CRecordView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_DIRECT, CRecordView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_PREVIEW, CRecordView::OnFilePrintPreview)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CBaseView construction/destruction

CBaseView::CBaseView()
	: CRecordView(CBaseView::IDD)
{
	//{{AFX_DATA_INIT(CBaseView)
	m_pSet = NULL;
	//}}AFX_DATA_INIT
	m_bAddMode = false;
}

CBaseView::~CBaseView()
{
}

void CBaseView::DoDataExchange(CDataExchange* pDX)
{
	CRecordView::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CBaseView)
	DDX_Control(pDX, IDC_SECTION, m_Section);
	DDX_Control(pDX, IDC_COURSE, m_List);
	DDX_FieldText(pDX, IDC_INSTRUCTOR, m_pSet->m_InstructorID, m_pSet);
	DDX_FieldText(pDX, IDC_ROOM, m_pSet->m_RoomNo, m_pSet);
	DDX_FieldText(pDX, IDC_SCHEDULE, m_pSet->m_Schedule, m_pSet);
	DDX_FieldText(pDX, IDC_CAPACITY, m_pSet->m_Capacity, m_pSet);
	DDX_FieldCBString(pDX, IDC_COURSE, m_pSet->m_CourseID, m_pSet);
	DDX_FieldText(pDX, IDC_SECTION, m_pSet->m_SectionNo, m_pSet);
	//}}AFX_DATA_MAP
}

BOOL CBaseView::PreCreateWindow(CREATESTRUCT& cs)
{
	return CRecordView::PreCreateWindow(cs);
}

void CBaseView::OnInitialUpdate()
{
	CBaseDoc* pDoc = GetDocument();		//  ?
										//  2  -  1- [Section]
	m_pSet = &pDoc->m_sectionSet;
										//    
	pDoc->m_courseSet.m_strSort = "CourseID";
										//     ,  
	if (!pDoc->m_courseSet.Open())
		return;
										//    
	m_pSet->m_strFilter = "CourseID = ?";
										//   
	m_pSet->m_sParam = pDoc->m_courseSet.m_CourseID;
										//    
	m_pSet->m_strSort = "SectionNo";
										//     
	m_pSet->m_pDatabase = pDoc->m_courseSet.m_pDatabase;
										//    [Section]
	CRecordView::OnInitialUpdate();
										//   
	GetParentFrame()->RecalcLayout();
	ResizeParentToFit();
										//  Combo Box
	m_List.ResetContent();
										//     [Course]
	if (pDoc->m_courseSet.IsOpen())
	{
		while (!pDoc->m_courseSet.IsEOF())
		{								//    
										//  
			m_List.AddString (pDoc->m_courseSet.m_CourseID);
										//    
			pDoc->m_courseSet.MoveNext();
		}
	}
	m_List.SetCurSel(0);	//   
}

/////////////////////////////////////////////////////////////////////////////
// CBaseView printing

BOOL CBaseView::OnPreparePrinting(CPrintInfo* pInfo)
{
	// default preparation
	return DoPreparePrinting(pInfo);
}

void CBaseView::OnBeginPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
}

void CBaseView::OnEndPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
}

/////////////////////////////////////////////////////////////////////////////
// CBaseView diagnostics

#ifdef _DEBUG
void CBaseView::AssertValid() const
{
	CRecordView::AssertValid();
}

void CBaseView::Dump(CDumpContext& dc) const
{
	CRecordView::Dump(dc);
}

CBaseDoc* CBaseView::GetDocument() // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CBaseDoc)));
	return (CBaseDoc*)m_pDocument;
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CBaseView database support
CRecordset* CBaseView::OnGetRecordset()
{
	return m_pSet;
}


/////////////////////////////////////////////////////////////////////////////
// CBaseView message handlers

void CBaseView::OnSelendokCourse() 
{
	if (!m_pSet->IsOpen())
		return;						//    , 
									//      
									//     m_pSet->m_sParam
	m_List.GetLBText(m_List.GetCurSel(),m_pSet->m_sParam);
									
	if (m_bAddMode)					//       
		return;

	m_pSet->Requery();				//  

	if (m_pSet->IsEOF())
	{								//   ,   
		m_pSet->SetFieldNull(&(m_pSet->m_CourseID), FALSE);
		m_pSet->m_CourseID = m_pSet->m_sParam;
	}
	UpdateData(FALSE);				//     
}

void CBaseView::OnRecordAdd()
{									//   
	if (m_bAddMode)
		OnMove(ID_RECORD_FIRST);
									//    
	CString sCourse = m_pSet->m_CourseID;
			//    .     
	m_pSet->AddNew();
			//    
	m_pSet->SetFieldNull(&(m_pSet->m_CourseID), FALSE);
			//   
	m_pSet->m_CourseID = sCourse;
	m_bAddMode = true;				//   
			//     
	m_Section.SetReadOnly(FALSE);
	UpdateData(FALSE);				//     
}

void CBaseView::OnRecordRefresh()
{									//  
	if (m_bAddMode)
	{								//     ,
		m_pSet->Move(0);			//    
									//     Section
		m_Section.SetReadOnly(TRUE);
		m_bAddMode = false;			//   
	}
	UpdateData(FALSE);				//     
}

void CBaseView::OnRecordDelete()
{									//  
	TRY								//    
	{
		m_pSet->Delete();
	}
	CATCH(CDBException, e)			//  
	{
									//   
		AfxMessageBox(e->m_strError);
		return;	
	}								//    
	END_CATCH						//  
	
	m_pSet->Requery();
	UpdateData(FALSE);				//     
}

BOOL CBaseView::OnMove(UINT nIDMoveCommand)
{
	if (m_bAddMode)
	{								//    
		if (!UpdateData())
			return FALSE;			//     
		
		if (m_pSet->CanUpdate())	//      CRecordset::readOnly,
			m_pSet->Update();		//     

		m_pSet->Requery();			//    ()
		UpdateData(FALSE);			//    
									//    Section
		m_Section.SetReadOnly(TRUE);
		m_bAddMode = false;			//   
		return TRUE;				//  
	}								//    ( ),
	else							//     
		return CRecordView::OnMove(nIDMoveCommand);	
}
